==> haskell-ixset-typed-0.3.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-5RO7E7ePKmT6v8zFAh9BRu
key: ixset-typed-0.3.1-5RO7E7ePKmT6v8zFAh9BRu
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: d879818aa9f94b50e016f1fdf3111a2c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/ixset-typed-0.3.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-5RO7E7ePKmT6v8zFAh9BRu
depends:
    base-4.9.1.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3.2-5SREq489x6g9JqiCFSVfmJ
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.3.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-Ia8T5XdBqgYJ8HST4usoHQ
key: ixset-typed-0.3.1-Ia8T5XdBqgYJ8HST4usoHQ
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: 6603b1767229a44ad343f28d42ec9505
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/ixset-typed-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-Ia8T5XdBqgYJ8HST4usoHQ
depends:
    base-4.9.1.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3.2-5SREq489x6g9JqiCFSVfmJ
    syb-0.7-4OKdCpwGutyB1rNRmoa0ya template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
